@@ -1,11 +1,9 @@
+from dataclasses import dataclass
 from itertools import product
 
 from justwatch import details, offers_for_countries, search
 
 
-from dataclasses import dataclass
-
-
 @dataclass
 class Base:
     base_field_1: int
@@ -22,9 +20,12 @@ def main():
     # result = details("ts4")  # Breaking Bad
     # result = details("tss25")  # Breaking Bad S5
     # result = details("tse411")  # Breaking Bad S5E1
-    # result = details("tm10")  # The Matrix
-    result = details("ts20711")  # The Simpsons
+    # result = details("tm10")
+    # print(result)  # The Matrix
+    # result = details("ts20711")  # The Simpsons
+    # result = details("tm118477")  # Haker (2002)
     # result = search("The Simpsons")
+    result = search("The Matrix", "US", "en", 3, True)
     print(result)
     print()
 
